==> pytest-base-url-1.0.0.tar.gz: pytest-base-url-1.0.0/setup.py <==
from setuptools import setup

setup(name='pytest-base-url',
      version='1.0.0',
      description='pytest plugin for URL based testing',
      long_description=open('README.rst').read(),
      author='Dave Hunt',
      author_email='dhunt@mozilla.com',
      url='https://github.com/davehunt/pytest-base-url',
      packages=['pytest_base_url'],
      install_requires=[
        'pytest>=2.7.3',
        'requests'],
      entry_points={'pytest11': ['base_url = pytest_base_url.plugin']},
      license='Mozilla Public License 2.0 (MPL 2.0)',
      keywords='py.test pytest base url mozilla automation',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Framework :: Pytest',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)',
          'Operating System :: POSIX',
          'Operating System :: Microsoft :: Windows',
          'Operating System :: MacOS :: MacOS X',
          'Topic :: Software Development :: Quality Assurance',
          'Topic :: Software Development :: Testing',
          'Topic :: Utilities',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy'])

==> pytest-base-url-1.1.0.tar.gz: pytest-base-url-1.1.0/setup.py <==
from setuptools import setup

setup(name='pytest-base-url',
      version='1.1.0',
      description='pytest plugin for URL based testing',
      long_description=open('README.rst').read(),
      author='Dave Hunt',
      author_email='dhunt@mozilla.com',
      url='https://github.com/pytest-dev/pytest-base-url',
      packages=['pytest_base_url'],
      install_requires=[
          'pytest>=2.7.3',
          'requests'],
      entry_points={'pytest11': ['base_url = pytest_base_url.plugin']},
      license='Mozilla Public License 2.0 (MPL 2.0)',
      keywords='py.test pytest base url mozilla automation',
      classifiers=[
          'Development Status :: 5 - Production/Stable',
          'Framework :: Pytest',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: Mozilla Public License 2.0 (MPL 2.0)',
          'Operating System :: POSIX',
          'Operating System :: Microsoft :: Windows',
          'Operating System :: MacOS :: MacOS X',
          'Topic :: Software Development :: Quality Assurance',
          'Topic :: Software Development :: Testing',
          'Topic :: Utilities',
          'Programming Language :: Python',
          'Programming Language :: Python :: 2.6',
          'Programming Language :: Python :: 2.7',
          'Programming Language :: Python :: 3.3',
          'Programming Language :: Python :: 3.4',
          'Programming Language :: Python :: 3.5',
          'Programming Language :: Python :: Implementation :: CPython',
          'Programming Language :: Python :: Implementation :: PyPy'])
